@@ -29,7 +29,6 @@ Copyright_License {
 #include "Dialogs/XML.hpp"
 #include "UIGlobals.hpp"
 #include "Form/Form.hpp"
-#include "Form/Edit.hpp"
 #include "Form/List.hpp"
 #include "Form/Button.hpp"
 #include "Widget/DockWindow.hpp"
@@ -42,14 +41,9 @@ Copyright_License {
 #include "MainWindow.hpp"
 #include "Interface.hpp"
 #include "Components.hpp"
-#include "GlideSolvers/GlidePolar.hpp"
-#include "GlideSolvers/GlideState.hpp"
-#include "GlideSolvers/MacCready.hpp"
 #include "Task/TaskManager.hpp"
 #include "Task/ProtectedTaskManager.hpp"
 #include "Compiler.h"
-#include "Compatibility/path.h"
-#include "Util/Macros.hpp"
 #include "Language/Language.hpp"
 #include "Waypoint/LastUsed.hpp"
 #include "Profile/Profile.hpp"
@@ -303,7 +297,7 @@ OnImagePaint(gcc_unused WndOwnerDrawFrame *sender, Canvas &canvas)
 // TODO: support other platforms
 
 class WaypointExternalFileListHandler final
-  : public ListControl::Handler {
+  : public ListItemRenderer, public ListCursorHandler {
 public:
   virtual void OnPaintItem(Canvas &canvas, const PixelRect rc,
                            unsigned idx) override;
@@ -423,7 +417,8 @@ dlgWaypointDetailsShowModal(const Waypoint &_waypoint,
   int num_files = std::distance(waypoint->files_external.begin(),
                                 waypoint->files_external.end());
   if (num_files > 0) {
-    wFilesList->SetHandler(&handler);
+    wFilesList->SetItemRenderer(&handler);
+    wFilesList->SetCursorHandler(&handler);
 
     unsigned list_height = wFilesList->GetItemHeight() * std::min(num_files, 5);
     wFilesList->Resize(wFilesList->GetWidth(), list_height);
