@@ -21,7 +21,7 @@
  */
 
 #include "MixedTaskFactory.hpp"
-#include "TaskFactoryConstraints.hpp"
+#include "Constraints.hpp"
 #include "Util/Macros.hpp"
 
 static constexpr TaskFactoryConstraints mixed_constraints = {
