@@ -28,9 +28,7 @@ Copyright_License {
 #include "Time/PeriodClock.hpp"
 #include "Math/fixed.hpp"
 
-class DataFieldFloat : public NumberDataField
-{
-private:
+class DataFieldFloat final : public NumberDataField {
   fixed mValue;
   fixed mMin;
   fixed mMax;
@@ -46,7 +44,6 @@ private:
 protected:
   fixed SpeedUp(bool keyup);
 
-
 public:
   DataFieldFloat(const TCHAR *EditFormat, const TCHAR *DisplayFormat,
                  fixed Min, fixed Max, fixed Default,
@@ -56,19 +53,19 @@ public:
      mSpeedup(0), mFine(Fine),
      unit(_T("")) {}
 
+  DataFieldFloat(const TCHAR *edit_format, const TCHAR *display_format,
+                 fixed _min, fixed _max, fixed _value,
+                 fixed _step, bool _fine,
+                 DataFieldListener *listener=nullptr)
+    :NumberDataField(Type::REAL, true, edit_format, display_format, listener),
+     mValue(_value), mMin(_min), mMax(_max), mStep(_step),
+     mSpeedup(0), mFine(_fine),
+     unit(_T("")) {}
+
   void SetUnits(const TCHAR *text) {
     unit = text;
   }
 
-  void Inc();
-  void Dec();
-  virtual ComboList *CreateComboList() const;
-  void SetFromCombo(int iDataFieldIndex, TCHAR *sValue);
-
-  virtual int GetAsInteger() const;
-  virtual const TCHAR *GetAsString() const;
-  virtual const TCHAR *GetAsDisplayString() const;
-
   void Set(fixed _value) {
     mValue = _value;
   }
@@ -93,9 +90,18 @@ public:
     return mStep;
   }
 
-  virtual void SetAsInteger(int Value);
   void SetAsFloat(fixed Value);
-  virtual void SetAsString(const TCHAR *Value);
+
+  /* virtual methods from class DataField */
+  virtual void Inc() override;
+  virtual void Dec() override;
+  virtual int GetAsInteger() const override;
+  virtual const TCHAR *GetAsString() const override;
+  virtual const TCHAR *GetAsDisplayString() const override;
+  virtual void SetAsInteger(int value) override;
+  virtual void SetAsString(const TCHAR *value) override;
+  virtual ComboList CreateComboList(const TCHAR *reference) const override;
+  virtual void SetFromCombo(int iDataFieldIndex, TCHAR *sValue) override;
 
 protected:
   void AppendComboValue(ComboList &combo_list, fixed value) const;
