@@ -33,7 +33,7 @@ Copyright_License {
 #include <assert.h>
 #include <winuser.h>
 
-static UPixelScalar
+static unsigned
 GetTabLineHeight()
 {
   return Layout::Scale(1);
@@ -212,10 +212,10 @@ void
 TabMenuDisplay::PaintMainMenuBorder(Canvas &canvas) const
 {
   const TabMenuControl &tb = GetTabMenuBar();
-  const UPixelScalar bwidth = GetTabLineHeight();
+  const unsigned bwidth = GetTabLineHeight();
 
   const PixelRect rcFirst = tb.GetMainMenuButtonSize(0);
-  const UPixelScalar menuBottom = tb.GetMainMenuButtonSize(
+  const unsigned menuBottom = tb.GetMainMenuButtonSize(
       tb.GetNumMainMenuItems() - 1).bottom;
   const PixelRect rcBlackBorder(rcFirst.left - bwidth, rcFirst.top - bwidth,
                                 rcFirst.right + bwidth, menuBottom + bwidth);
@@ -230,7 +230,7 @@ TabMenuDisplay::PaintMainMenuItems(Canvas &canvas,
   const TabMenuControl &tb = GetTabMenuBar();
   PaintMainMenuBorder(canvas);
 
-  const bool is_focused = HasFocus();
+  const bool is_focused = !HasCursorKeys() || HasFocus();
 
   unsigned main_menu_index = 0;
   for (auto i = tb.GetMainMenuButtons().begin(),
@@ -251,7 +251,7 @@ TabMenuDisplay::PaintMainMenuItems(Canvas &canvas,
                                                            is_focused,
                                                            isDown));
 
-    const PixelRect rc = tb.GetMainMenuButtonSize(main_menu_index);
+    const PixelRect &rc = tb.GetMainMenuButtonSize(main_menu_index);
     TabDisplay::PaintButton(canvas, CaptionStyle, gettext(button.caption), rc,
                             NULL, isDown, inverse);
   }
@@ -262,8 +262,8 @@ TabMenuDisplay::PaintSubMenuBorder(Canvas &canvas,
                                    const MainMenuButton &main_button) const
 {
   const TabMenuControl &tb = GetTabMenuBar();
-  const UPixelScalar bwidth =  GetTabLineHeight();
-  const UPixelScalar subTop =
+  const unsigned bwidth = GetTabLineHeight();
+  const unsigned subTop =
     tb.GetSubMenuButtonSize(main_button.first_page_index).top;
   const PixelRect bLast = tb.GetSubMenuButtonSize(main_button.last_page_index);
   const PixelRect rcBlackBorder(bLast.left - bwidth, subTop - bwidth,
@@ -289,7 +289,7 @@ TabMenuDisplay::PaintSubMenuItems(Canvas &canvas,
   assert(main_button.first_page_index < tb.GetTabButtons().size());
   assert(main_button.last_page_index < tb.GetTabButtons().size());
 
-  const bool is_focused = HasFocus();
+  const bool is_focused = !HasCursorKeys() || HasFocus();
 
   for (unsigned first_page_index = main_button.first_page_index,
          last_page_index = main_button.last_page_index,
@@ -325,7 +325,7 @@ TabMenuDisplay::OnPaint(Canvas &canvas)
   canvas.Clear(look.background_color);
   canvas.Select(*look.button.font);
 
-  const unsigned caption_style = DT_EXPANDTABS | DT_CENTER | DT_NOCLIP
+  const unsigned caption_style = DT_CENTER | DT_NOCLIP
       | DT_WORDBREAK;
 
   PaintMainMenuItems(canvas, caption_style);
