@@ -28,18 +28,11 @@ Copyright_License {
 #include "Screen/UnitSymbol.hpp"
 #include "Screen/Layout.hpp"
 #include "Screen/FastPixelRotation.hpp"
-#include "LogFile.hpp"
 #include "Units/Units.hpp"
 #include "Util/Clamp.hpp"
 
-#include <assert.h>
-#include <stdio.h>
-
 #include <algorithm>
 
-using std::min;
-using std::max;
-
 #define DELTA_V_STEP fixed(4)
 #define DELTA_V_LIMIT fixed(16)
 #define TEXT_BUG _T("Bug")
@@ -413,9 +406,7 @@ GaugeVario::RenderValue(Canvas &canvas, PixelScalar x, PixelScalar y,
     value_info->last_unit = Units::current.vertical_speed_unit;
     const UnitSymbol *unit_symbol = units_look.GetSymbol(value_info->last_unit);
     unit_symbol->Draw(canvas, x - Layout::Scale(5), value_info->rc.top,
-                      look.inverse
-                      ? UnitSymbol::INVERSE_GRAY
-                      : UnitSymbol::GRAY);
+                      look.background_color, COLOR_GRAY);
   }
 }
 
