@@ -24,11 +24,10 @@ Copyright_License {
 #include "MapWindow.hpp"
 #include "Look/MapLook.hpp"
 #include "Geo/GeoClip.hpp"
-#include "Screen/Icon.hpp"
 #include "Task/ProtectedRoutePlanner.hpp"
 
 #ifdef ENABLE_OPENGL
-#include "Screen/OpenGL/Triangulate.hpp"
+#include "Screen/OpenGL/Scope.hpp"
 #endif
 
 #include <stdio.h>
@@ -288,7 +287,7 @@ MapWindow::DrawTerrainAbove(Canvas &canvas)
 
     visitor.fans.Prepare();
 
-    glEnable(GL_STENCIL_TEST);
+    const GLEnable stencil_test(GL_STENCIL_TEST);
     glClear(GL_STENCIL_BUFFER_BIT);
 
     glColorMask(GL_FALSE, GL_FALSE, GL_FALSE, GL_FALSE);
@@ -303,14 +302,10 @@ MapWindow::DrawTerrainAbove(Canvas &canvas)
     glStencilFunc(GL_NOTEQUAL, 1, 1);
     glStencilOp(GL_KEEP, GL_KEEP, GL_KEEP);
 
-    glEnable(GL_BLEND);
-    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    const GLBlend blend(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
     canvas.Clear(Color(255, 255, 255, 77));
 
-    glDisable(GL_BLEND);
-    glDisable(GL_STENCIL_TEST);
-
 #elif defined(USE_GDI)
 
     // Get a buffer for drawing a mask
@@ -341,7 +336,10 @@ MapWindow::DrawTerrainAbove(Canvas &canvas)
     visitor.fans.DrawFill(buffer);
 
     // Copy everything non-white to the buffer
-    canvas.CopyTransparentWhite(buffer);
+    canvas.CopyTransparentWhite(0, 0,
+                                render_projection.GetScreenWidth(),
+                                render_projection.GetScreenHeight(),
+                                buffer, 0, 0);
 
     /* skip the separate terrain line step below, because we have done
        it already */
@@ -402,7 +400,7 @@ MapWindow::DrawTerrainAbove(Canvas &canvas)
 
   glDisable(GL_STENCIL_TEST);
 
-#elif defined(USE_GDI)
+#elif defined(USE_GDI) || defined(USE_MEMORY_CANVAS)
 
   // Get a buffer for drawing a mask
   Canvas &buffer = buffer_canvas;
@@ -430,7 +428,10 @@ MapWindow::DrawTerrainAbove(Canvas &canvas)
   visitor.fans.DrawFill(buffer);
 
   // Copy everything non-white to the buffer
-  canvas.CopyTransparentWhite(buffer);
+  canvas.CopyTransparentWhite(0, 0,
+                              render_projection.GetScreenWidth(),
+                              render_projection.GetScreenHeight(),
+                              buffer, 0, 0);
 
 #endif
   }
