@@ -29,7 +29,7 @@ CirclingInfo::Clear()
   turning = false;
   circling = false;
 
-  turn_rate = turn_rate_heading = fixed(0);
+  turn_rate = turn_rate_heading = Angle::Zero();
 
   time_cruise = fixed(0);
   time_climb = fixed(0);
@@ -40,7 +40,7 @@ CirclingInfo::Clear()
 
   max_height_gain = fixed(0);
 
-  turn_rate_smoothed = fixed(0);
+  turn_rate_smoothed = turn_rate_heading_smoothed = Angle::Zero();
   turn_mode = CirclingMode::CRUISE;
 
   circling_percentage = fixed(-1);
