@@ -38,6 +38,12 @@
 #include <unistd.h>
 #include <sys/types.h>
 
+#ifdef __linux__
+#define HAVE_EVENTFD
+#define HAVE_SIGNALFD
+#include <signal.h>
+#endif
+
 /**
  * An OO wrapper for a UNIX file descriptor.
  */
@@ -110,6 +116,11 @@ public:
    */
   void SetNonBlocking();
 
+  /**
+   * Enable blocking mode on this file descriptor.
+   */
+  void SetBlocking();
+
   /**
    * Duplicate the file descriptor onto the given file descriptor.
    */
@@ -118,6 +129,14 @@ public:
   }
 #endif
 
+#ifdef HAVE_EVENTFD
+  bool CreateEventFD(unsigned initval=0);
+#endif
+
+#ifdef HAVE_SIGNALFD
+  bool CreateSignalFD(const sigset_t *mask);
+#endif
+
   /**
    * Close the file descriptor.  It is legal to call it on an
    * "undefined" object.  After this call, IsDefined() is guaranteed
