@@ -21,7 +21,7 @@
 */
 
 #include "Deserialiser.hpp"
-#include "Task/Ordered/OrderedTaskBehaviour.hpp"
+#include "Task/Ordered/Settings.hpp"
 #include "Task/Ordered/OrderedTask.hpp"
 #include "Task/Ordered/Points/StartPoint.hpp"
 #include "Task/Ordered/Points/FinishPoint.hpp"
@@ -34,7 +34,6 @@
 #include "XML/DataNode.hpp"
 #include "Engine/Waypoint/Waypoints.hpp"
 
-#include <assert.h>
 #include <memory>
 
 void
@@ -185,7 +184,6 @@ Deserialiser::DeserialiseOZ(const Waypoint &wp, bool is_turnpoint)
   else if (StringIsEqual(type, _T("BGAEnhancedOption")))
     return KeyholeZone::CreateBGAEnhancedOptionZone(wp.location);
 
-  assert(1);
   return nullptr;
 }
 
@@ -248,9 +246,11 @@ Deserialiser::DeserialiseWaypoint()
 }
 
 void 
-Deserialiser::Deserialise(OrderedTaskBehaviour &data)
+Deserialiser::Deserialise(OrderedTaskSettings &data)
 {
   node.GetAttribute(_T("aat_min_time"), data.aat_min_time);
+  node.GetAttribute(_T("start_requires_arm"),
+                    data.start_constraints.require_arm);
   node.GetAttribute(_T("start_max_speed"), data.start_constraints.max_speed);
   node.GetAttribute(_T("start_max_height"), data.start_constraints.max_height);
   data.start_constraints.max_height_ref =
@@ -273,9 +273,9 @@ Deserialiser::Deserialise(OrderedTask &task)
   task.SetFactory(GetTaskFactoryType());
   task.Reset();
 
-  OrderedTaskBehaviour beh = task.GetOrderedTaskBehaviour();
+  OrderedTaskSettings beh = task.GetOrderedTaskSettings();
   Deserialise(beh);
-  task.SetOrderedTaskBehaviour(beh);
+  task.SetOrderedTaskSettings(beh);
 
   const DataNode::List children = node.ListChildrenNamed(_T("Point"));
   for (const auto &i : children) {
@@ -321,6 +321,5 @@ Deserialiser::GetTaskFactoryType() const
   else if (StringIsEqual(type, _T("Touring")))
     return TaskFactoryType::TOURING;
 
-  assert(1);
   return TaskFactoryType::FAI_GENERAL;
 }
