@@ -24,8 +24,8 @@ Copyright_License {
 #include "UtilsSettings.hpp"
 #include "Protection.hpp"
 #include "Look/Look.hpp"
+#include "Look/GlobalFonts.hpp"
 #include "MainWindow.hpp"
-#include "MapWindow/GlueMapWindow.hpp"
 #include "Computer/Settings.hpp"
 #include "MapSettings.hpp"
 #include "Terrain/RasterTerrain.hpp"
@@ -34,14 +34,11 @@ Copyright_License {
 #include "Topography/TopographyGlue.hpp"
 #include "Dialogs/Dialogs.h"
 #include "Device/device.hpp"
-#include "Message.hpp"
-#include "Polar/PolarGlue.hpp"
 #include "Components.hpp"
 #include "Interface.hpp"
 #include "ActionInterface.hpp"
 #include "Language/Language.hpp"
 #include "LogFile.hpp"
-#include "Simulator.hpp"
 #include "DrawThread.hpp"
 #include "Airspace/AirspaceGlue.hpp"
 #include "Airspace/ProtectedAirspaceWarningManager.hpp"
@@ -50,7 +47,6 @@ Copyright_License {
 #include "Operation/VerboseOperationEnvironment.hpp"
 #include "Task/ProtectedTaskManager.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
-#include "Engine/Task/TaskEvents.hpp"
 #include "Waypoint/WaypointGlue.hpp"
 #include "Computer/GlideComputer.hpp"
 #include "Language/LanguageGlue.hpp"
@@ -156,8 +152,6 @@ SettingsLeave(const UISettings &old_ui_settings)
       delete task;
 
       way_points.Optimise();
-
-      lease->FillMatPoints(way_points);
     }
   }
 
@@ -180,12 +174,12 @@ SettingsLeave(const UISettings &old_ui_settings)
 
   if (AirspaceFileChanged) {
     if (glide_computer != NULL)
-      glide_computer->GetAirspaceWarnings().clear();
+      glide_computer->GetAirspaceWarnings().Clear();
 
     if (glide_computer != NULL)
       glide_computer->ClearAirspaces();
 
-    airspace_database.clear();
+    airspace_database.Clear();
     ReadAirspace(airspace_database, terrain,
                  CommonInterface::GetComputerSettings().pressure,
                  operation);
@@ -207,7 +201,8 @@ SettingsLeave(const UISettings &old_ui_settings)
     main_window.SetLook().map.trail.Initialise(settings_map.trail);
 
   if (settings_map.waypoint.landable_style != old_settings_map.waypoint.landable_style)
-    main_window.SetLook().map.waypoint.Initialise(settings_map.waypoint);
+    main_window.SetLook().map.waypoint.Initialise(settings_map.waypoint,
+                                                  Fonts::map, Fonts::map_bold);
 
   ResumeAllThreads();
   main_window.ResumeThreads();
@@ -219,6 +214,7 @@ SettingsLeave(const UISettings &old_ui_settings)
 
   operation.Hide();
   InfoBoxManager::SetDirty();
+  main_window.FlushRendererCaches();
   main_window.FullRedraw();
   main_window.SetDefaultFocus();
 }
